==> haskell-quickcheck-safe-0.1.0.6-145-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck-safe
version:              0.1.0.6
visibility:           public
id:                   QuickCheck-safe-0.1.0.6-6Ng8zOzIi07898IC0oxutO
key:                  QuickCheck-safe-0.1.0.6-6Ng8zOzIi07898IC0oxutO
license:              MIT
copyright:            2015,2017 Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
synopsis:             Safe reimplementation of QuickCheck'\''s core
description:
    QuickCheck-safe reimplements the quickCheck functionality with a pure
    interface and a very small trusted base (see Test.QuickCheck.Safe.Trusted).

    * uses the existing Arbitrary instances
    * implemented features: testing, result minimization (i.e., shrinking)
    * missing features: expected failures, label frequencies, coverage

    The package is targeted at users who want to leverage SafeHaskell for
    sandboxing.

    >>> putStr $ quickCheck (inventQCGen ()) (\x -> length (x :: [()]) < 10)
    *** Failed! Falsifiable (after 18 tests and 3 shrinks):
    [(),(),(),(),(),(),(),(),(),(),(),(),(),(),()]

category:             Testing
abi:                  18670bc003abeb6ce19936b54759dad6
exposed:              True
exposed-modules:      Test.QuickCheck.Safe Test.QuickCheck.Safe.Trusted
import-dirs:          /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-safe
hs-libraries:         HSQuickCheck-safe-0.1.0.6-6Ng8zOzIi07898IC0oxutO
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-safe/html/QuickCheck-safe.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-safe/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-safe-0.1.0.6-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-safe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck-safe
version:              0.1.0.6
visibility:           public
id:                   QuickCheck-safe-0.1.0.6-FOVX1MeRANYE57eCw8qL73
key:                  QuickCheck-safe-0.1.0.6-FOVX1MeRANYE57eCw8qL73
license:              MIT
copyright:            2015,2017 Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
synopsis:             Safe reimplementation of QuickCheck'\''s core
description:
    QuickCheck-safe reimplements the quickCheck functionality with a pure
    interface and a very small trusted base (see Test.QuickCheck.Safe.Trusted).

    * uses the existing Arbitrary instances
    * implemented features: testing, result minimization (i.e., shrinking)
    * missing features: expected failures, label frequencies, coverage

    The package is targeted at users who want to leverage SafeHaskell for
    sandboxing.

    >>> putStr $ quickCheck (inventQCGen ()) (\x -> length (x :: [()]) < 10)
    *** Failed! Falsifiable (after 18 tests and 3 shrinks):
    [(),(),(),(),(),(),(),(),(),(),(),(),(),(),()]

category:             Testing
abi:                  045e6be7974ccdbf2fd191511e641559
exposed:              True
exposed-modules:      Test.QuickCheck.Safe Test.QuickCheck.Safe.Trusted
import-dirs:          /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/QuickCheck-safe-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-safe
hs-libraries:         HSQuickCheck-safe-0.1.0.6-FOVX1MeRANYE57eCw8qL73
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-safe/html/QuickCheck-safe.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-safe/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
